!!! warning

    This page is redundant with the unified docs in `biocypher/documentation`.
    Community docs will be maintained there.

Welcome to the BioCypher community! We follow open-source principles and
encourage any sort of contribution. We communicate on GitHub, where we also
organise our projects. For more informal discussions and updates, we have a
[Zulip channel](https://biocypher.zulipchat.com). Everybody is welcome!

<div class="grid cards" markdown>

-   :octicons-book-24:{ .lg .middle } __Where to Start__

    ---

    If you'd like to learn how to contribute to our projects, please follow
    the steps outlined in the contribution guide.

    [:octicons-arrow-right-24: To the contribution guide](contribute.md)

</div>

## Our Community Zulip Channel

Some channels are public, others can be seen after joining the Zulip community
(free of charge).

- `#announcements`: Stay informed about seminars, workshops, and other events.
- `#help`: Ask questions and get help related to BioCypher ecosystem projects.
- `#general`: You can introduce yourselves, discuss ideas and share your work.
- `#development`: Exchange ideas about development of BioCypher ecosystem projects.

Why Zulip? We chose Zulip because it is a modern, open-source alternative to
Slack. It is organised by topics, which helps in keeping the discussions
focused. It also is free of charge for open-source and academic projects, which
means that they sponsor the cloud hosting for our channel (as for many other
open-source projects) - thanks!

Sign up [here](https://biocypher.zulipchat.com/).

## Contributing Guidelines GitHub Links

- [Contribution guidelines](https://github.com/biocypher/biocypher/blob/main/CONTRIBUTING.md)

- [Code of Conduct](https://github.com/biocypher/biocypher/blob/main/CODE_OF_CONDUCT.md)

- [Developer Guide](https://github.com/biocypher/biocypher/blob/main/DEVELOPER.md)
